import 'package:flutter/material.dart';
import 'package:weoveri_flutter_widgets/buttons/parallalogram_painter.dart';

import '../utils/enums.dart';

/// A button that is tilt from sides and accept a `Text` in the center
class WOIParallalogramButton extends StatelessWidget {
  const WOIParallalogramButton({
    Key? key,
    this.onPressed,
    this.buttonColor = Colors.black,
    this.borderColor,
    this.borderWdth = 1,
    this.margin,
    this.height = 50,
    this.width,
    this.boxShadow,
    this.tilt = 10,
    required this.text,
    this.textStyle,
    this.textMargin,
    this.tiltSide = TiltSide.right,
  }) : super(key: key);

  final String text;
  final VoidCallback? onPressed;
  final Color buttonColor;
  final List<BoxShadow>? boxShadow;
  final Color? borderColor;
  final double borderWdth;
  final EdgeInsetsGeometry? margin;
  final double height;
  final double? width;
  final double tilt;
  final TextStyle? textStyle;
  final EdgeInsets? textMargin;
  final TiltSide? tiltSide;

  @override
  Widget build(BuildContext context) {
    return Container(
      height: height,
      width: width,
      decoration: BoxDecoration(
        boxShadow: boxShadow,
        gradient: const LinearGradient(
          colors: [
            Colors.black,
            Colors.white,
            Colors.blue,
          ],
        ),
      ),
      child: GestureDetector(
        onTap: onPressed!,
        child: CustomPaint(
          painter: WOIParallelogramPainter(
            tilt: tiltSide == TiltSide.right ? tilt : -tilt,
            borderColor: borderColor ?? buttonColor,
            borderWidth: borderWdth,
            buttonColor: buttonColor,
          ),
          child: Center(
            child: Padding(
              padding: textMargin ??
                  const EdgeInsets.symmetric(
                    horizontal: 24,
                  ),
              child: Text(
                text,
                style: textStyle ??
                    const TextStyle(
                      color: Colors.white,
                    ),
              ),
            ),
          ),
        ),
      ),
    );
  }
}
